/* global Ladda, icon */

"use strict";

$(document).ready(() => {
	initSelect2();
	eventos.init()
	defaultConfigDataTable()
	contratos.init()
});

const listaContratoSeleccionado = []
let tipoContrato = ''

// INICIALIZACION
//========================================

/** inicializa el select */
function initSelect2() {
	$('.select').select2({
		minimumResultsForSearch: Infinity
	});
}

function initDatePicker() {
	$('.datepicker_es').datepicker({
		dateFormat: 'dd/mm/yy',
		showButtonPanel: false
	})
}

const contratos = {
	init() {
		this.listarContrato()
	},
	listarContrato(json = {}) {
		$('#tblContrato').DataTable().destroy()
		$('#tblContrato').DataTable({
			ajax: {
				url: '../ContratoServlet?accion=listarContrato',
				type: 'POST',
				dataType: 'JSON',
				data: {
					json: JSON.stringify(json)
				}
			},
			processing: true,
			serverSide: true,
			responsive: true,
			iDisplayLength: 20,
			columns: [
				{
					data: 'codigoEstadoContrato',
					className: 'text-center',
					render: (data) => {
						if (data == 1) {
							return `<input class="styled ckbRegistro" type="checkbox">`
						}
						return ''
					}
				},
				{data: "nombrePersonal"},
				{
					data: null,
					render: (data) => {
						return `${data.tipoDocumentoIdentidad} - ${data.documentoIdentidad}`
					}
				},
				{data: "areaLaboral"},
				{data: "cargoLaboral"},
				{data: "fechaInicio"},
				{
					data: "tipoContrato",
					render: (data) => data || ''
				},
				{
					data: "razonSocial",
					render: (data) => data || ''
				},
				{
					data: "estadoContrato",
					className: 'text-center'
				},
				{
					data: 'codigoEstadoContrato',
					className: 'text-center',
					render: (data) => {
						let accion = `<ul class="icons-list">`
						if (data != 1) {
							accion += `
								<li><a class="btnVerPdf"><i class="icon-file-pdf text-danger"></i></a></li>
							`
						}
						accion += `</ul>`
						return accion
					}
				}
			],
			initComplete: () => {
				$(".styled").uniform({
					radioClass: 'choice',
					wrapperClass: 'border-primary-600 text-primary-800 div-checkbox-head'
				})
				eventos.verPdf()
				eventos.seleccionarCheckbox()
				eventos.seleccionarCheckboxTodo()
				eventos.modalPreVistaContrato()
			}
		})
	},
	listarContratoSeleccionado(columns) {
		$('#tblContratoSeleccionado').DataTable().destroy()
		$('#tblContratoSeleccionado').DataTable({
			data: listaContratoSeleccionado,
			responsive: true,
			paging: false,
			bInfo: false,
			columns: columns,
			initComplete: () => {
				initDatePicker()
			}
		})
	},
	actualizarContratoGenerado(arrayContrato, accion) {
		return new Promise((resolve, reject) => {
			$.ajax({
				url: '../ContratoServlet?accion=' + accion,
				type: 'POST',
				dataType: 'JSON',
				data: {
					jsonArray: JSON.stringify(arrayContrato)
				},
				success: function (data, textStatus, jqXHR) {
					resolve(data)
				}
			})
		})
	}
}

const eventos = {
	init() {
		this.buscarContrato()
		this.limpiarInputs()
		this.dataPreVista()
		this.generarPrevista()
		this.actualizarContrato()
	},
	buscarContrato() {
		querySelector('#btnBuscarContrato').addEventListener('click', () => {
			let params = cleanQueryParams({
				numeroDocumento: querySelector('#txtNumeroDocumentoIdentidad').value,
				apellido: querySelector('#txtApellidos').value,
				estado: querySelector('#cboEstadoContratoPlanilla').value,
				tipo: querySelector('#cboTipoContratoPlanilla').value,
				razonSocial: querySelector('#cboRazonSocial').value,
				tipoTrabajador: querySelector('#cboTipoTrabajador').value
			})

			contratos.listarContrato(params)
		})
	},
	verPdf() {
		$('.btnVerPdf').off().on('click', (e) => {
			let dataRow = $('#tblContrato').DataTable().row($(e.currentTarget).parents('tr')).data()
			$('#data').val(JSON.stringify(dataRow));
			$('#formPDF').submit();
		})
	},
	limpiarInputs() {
		$('#btnLimpiarFiltroFichas').on('click', () => {
			$('#formBuscarContrato input').val('')
			$('#formBuscarContrato select').val('')
			initSelect2()
		})
	},
	seleccionarCheckboxTodo() {
		$('#ckbRegistroTodo').on('click', (ckb) => {
			seleccionarCheckBoxTodo(ckb.currentTarget)
		})
	},
	seleccionarCheckbox() {
		$('#tblContrato tbody').off().on('click', '.ckbRegistro', () => {
			seleccionarCheckBox()
		})
	},
	modalPreVistaContrato() {
		$('#btnGenerarContrato').on('click', () => {
			if ($('.ckbRegistro:checked').length > 0) {
				$('.ckbRegistro:checked').each((i, c) => {
					let dataRow = $('#tblContrato').DataTable().row($(c).parents('tr')).data()
					let bool = listaContratoSeleccionado.some(e => e.codigoContrato == dataRow.codigoContrato)
					if (!bool) {
						listaContratoSeleccionado.push(dataRow)
					}
				})
				$('#modalGenerarPrevista').modal('show')
			}
		})
	},
	dataPreVista() {
		$('#cbAsignarTipoContrato').on('change', (e) => {
			let tipoContrato = $(e.currentTarget).val()
			let inputs = ''

			if (tipoContrato != '') {
				inputs += `
        <div class="row">
          <div class="col-lg-12">
            <div class="form-group">
              <b>Razon social:</b>
              <select class="form-control select" id="cbRazonSocialAsignar" name="cbRazonSocialAsignar">
                <option value="">Seleccione una razon social</option>
                <option value="1">Saco Oliveros</option>
                <option value="2">Sistema Helicoidal</option>
                <option value="3">Apeiron</option>
              </select>
            </div>
          </div>      
        </div>`
				switch (tipoContrato) {
					case '1':
					case '2':
						inputs +=
							/*
							 * `<div class="col-lg-4">
							 <div class="form-group">
							 <b>Asignacion familiar:</b>
							 <input class="form-control" type="number" id="txtAsigancionFamiliar" name="txtAsigancionFamiliar">
							 </div>
							 </div>   `  							 
							 **/
							`<div class="row">
              <div class="col-lg-6">
                <div class="form-group">
                  <b>Transporte:</b>
                  <input class="form-control" type="number" id="txtTransporte" name="txtTransporte">
                </div>
              </div>      
              <div class="col-lg-6">
                <div class="form-group">
                  <b>Refrigerio:</b>
                  <input class="form-control" type="number" id="txtRefrigerio" name="txtRefrigerio">
                </div>
              </div>      
            </div>`
						break;
				}
			}

			$('#divCamposTipoContrato').html(inputs)
			initSelect2()
//			$('#cbSedeAsignar').append(createSelectOptions(optSedes, 'codigo', 'descripcion')).select2()
//			initDatePicker('#dpFechaInicio', '#dpFechaFin')
//			$('#cbRazonSocialAsignar,#cbTurnoAsignar').select2({
//				minimumResultsForSearch: Infinity
//			})
		})
	},
	generarPrevista() {
		$('#btnVerPrevista').on('click', () => {
			tipoContrato = $('#cbAsignarTipoContrato').val()
			let tipoContratoText = $('#cbAsignarTipoContrato option:selected').text()
			$('#lblTipoContrato').html(tipoContratoText)
			let codigoRazonSocial = $('#cbRazonSocialAsignar').val()
			let razonSocial = $('#cbRazonSocialAsignar option:selected').text()

			listaContratoSeleccionado.forEach(v => {
				v.codigoRazonSocial = codigoRazonSocial
				v.codigoTipoContrato = tipoContrato
			})

			let headArray =
				[
					{
						data: null,
						render: (data) => `${data.tipoDocumentoIdentidad} - ${data.documentoIdentidad}`,
						title: 'Numero de Documento'
					},
					{
						data: 'nombrePersonal',
						title: 'Personal'
					},
					{
						data: 'direccion',
						title: 'Direccion'
					},
					{
						data: 'areaLaboral',
						title: 'Area'
					},
					{
						data: 'cargoLaboral',
						title: 'Cargo'
					}
				]
			switch (tipoContrato) {
				case '1':
				case '2':
//					let asignacionFamiliar = $('#txtAsigancionFamiliar').val()
					let transporte = $('#txtTransporte').val()
					let refrigerio = $('#txtRefrigerio').val()

					headArray.push(
						{
							data: null,
							render: (data) => {
								let asignacionFamiliar = data.asignacionFamiliar ? data.asignacionFamiliar : 0
								let bruto = data.brutoMensual ? data.brutoMensual : 0
								let basico = parseFloat(bruto) - parseFloat(transporte) - (parseFloat(refrigerio) * 30) - parseFloat(asignacionFamiliar)
								return `<input type="number" value="${basico}" class="form-control suma txtBasicoContrato">`
							},
							title: 'Basico'
						},
						{
							data: 'asignacionFamiliar',
							render: (data) => `<input type="number" value="${data ? data : 0}" class="form-control suma txtAsignacionFamiliarContrato">`,
							title: 'Asignacion Familiar'
						},
						{
							data: null,
							render: () => `<input type="number" value="${transporte}" class="form-control suma txtTransporteContrato">`,
							title: 'Transporte'
						},
						{
							data: null,
							render: () => `<input type="number" value="${refrigerio}" class="form-control suma txtRefrigerioContrato" >`,
							title: 'Refrigerio'
						},
						{
							data: 'brutoMensual',
							render: (data) => `<span class="lblSueldoBruto">${data ? data : 0}</span>`,
							title: 'Sueldo Bruto'
						}
					)
					break;
				default:
			}

			headArray.push(
				{
					data: 'fechaInicio',
					render: (data) => `<input value="${data}" class="form-control datepicker_es dtFechaInicio">`,
					title: 'Fecha Inicio'
				},
				{
					data: 'fechaFin',
					render: (data) => `<input value="${data}" class="form-control datepicker_es dtFechaFin">`,
					title: 'Fecha Fin'
				},
				{
					data: null,
					render: () => `<span>${razonSocial}</span>`,
					title: 'Razon Social'
				},
				{
					data: null,
					render: () => `<span>${razonSocial}</span>`,
					title: 'Accion'
				}
			)

			$('#modalGenerarPrevista').modal('hide')

			let td = ''
			headArray.forEach(() => {
				td += '<th></th>'
			})

			$('#tblContratoSeleccionado thead tr').html(td)

			contratos.listarContratoSeleccionado(headArray)

			console.log(headArray)
		})
	},
	actualizarContrato() {
		$('#btnActualizarContrato').on('click', () => {

			let arrayActualizar = []

			$('#tblContratoSeleccionado tbody tr').each((i, v) => {
				let dataRow = $('#tblContratoSeleccionado').DataTable().row($(v)).data()

				switch (tipoContrato) {
					case '1':
					case '2':
						let basico = $(v).find('.txtBasicoContrato').val()
						let asignacionFamiliar = $(v).find('.txtAsignacionFamiliarContrato').val()
						let transporte = $(v).find('.txtTransporteContrato').val()
						let refrigerio = $(v).find('.txtRefrigerioContrato').val()
						let fechaInicio = $(v).find('.dtFechaInicio').val()
						let fechaFin = $(v).find('.dtFechaFin').val()

						dataRow.basico = basico
						dataRow.asignacionFamiliar = asignacionFamiliar
						dataRow.transporte = transporte
						dataRow.refrigerio = refrigerio
						dataRow.fechaInicio = fechaInicio
						dataRow.fechaFin = fechaFin

						arrayActualizar.push(dataRow)
						break;
					default:
				}

			})

			let accion = ''

			switch (tipoContrato) {
				case '1':
				case '2':
					accion = 'actualizarContratoGeneradoAdministrativo'
					break;
				default:
			}

			if (arrayActualizar.length > 0) {
				jAlert({
					type: 'confirm',
					content: 'Asegúrese de revisar bien la información de los sueldos de los contratos.',
					buttons: {left: 'Si', right: 'No'}
				}).then(flag => {
					if (flag) {
						contratos.actualizarContratoGenerado(arrayActualizar, accion)
							.then(data => {
								if (data.status) {
									jAlert({
										type: 'success',
										content: `Se hizo la peticion correctamente.`,
										buttons: {left: 'Aceptar'}
									}).then(flag => {
										if (flag) {
											window.location.reload()
										}
									})
								} else {
									jAlert({type: 'error', content: data.message, buttons: {left: 'Aceptar'}})
								}
							})
							.catch(err => jAlert({type: 'error', content: err, buttons: {left: 'Aceptar'}}))
					}
				})
			}
		})
	}
}



const querySelector = (node) => document.querySelector(node)

const querySelectorAll = (node) => document.querySelectorAll(node)

const cleanQueryParams = (params = {}) => {
	for (var key in params) {
		if (params.hasOwnProperty(key)) {
			if (!params[key]) {
				delete params[key];
			}
		}
	}

	return params;
}

const seleccionarCheckBoxTodo = (tr) => {
	if ($(tr).prop('checked')) {
		$('.ckbRegistro').prop('checked', true).uniform()
	} else {
		$('.ckbRegistro').prop('checked', false).uniform()
	}
}

const seleccionarCheckBox = () => {
	if ($('.ckbRegistro:checked').length === $('.ckbRegistro').length) {
		$('#ckbRegistroTodo').prop('checked', true).uniform()
	} else {
		$('#ckbRegistroTodo').prop('checked', false).uniform()
	}
}